@@ -13,19 +13,25 @@ Metadata
 Functionality
 -------------
 
-.. autofunction:: infer_pypackages_from_nb
-.. autofunction:: infer_pypackages_from_file
-.. autofunction:: check_consecutiveness
-.. autofunction:: set_version
+.. autosummary::
+   :toctree:
 
-Helpers
--------
+   infer_pypackages
+   check_consecutiveness
+   set_version
+
+Notebook file helpers
+---------------------
+
+.. autosummary::
+   :toctree:
+
+   Notebook
+   initialize_metadata
+   notebook_path
+   read_notebook
+   write_notebook
 
-.. autofunction:: initialize_metadata
-.. autoclass:: Notebook
-.. autofunction:: notebook_path
-.. autofunction:: read_notebook
-.. autofunction:: write_notebook
 """
 import nbproject_test as test
 
@@ -35,5 +41,5 @@ from ._jupyter_communicate import notebook_path
 from ._meta_live import MetaLive
 from ._meta_store import MetaContainer, MetaStore
 from ._notebook import Notebook, read_notebook, write_notebook
-from ._pypackage import infer_pypackages_from_file, infer_pypackages_from_nb
+from ._pypackage import infer_pypackages
 from ._set_version import set_version
